Here is the list of authors that contributed to this package:

* Pierre Palud <https://pierrepalud.github.io/>
* Pierre-Antoine Thouvenin <https://pthouvenin.github.io/>
* Pierre Chainais <http://pierrechainais.ec-lille.fr/>
* Franck Le Petit
* Emeric Bron
